VTickGroup — pyqtgraph 0.11.0rc0 documentation

# VTickGroup

class `pyqtgraph.` `VTickGroup`(xvals=None, yrange=None, pen=None)

  Bases: `UIGraphicsItem`

  Draws a set of tick marks which always occupy the same vertical range of the view, but have x coordinates relative to the data within the view.

  `__init__`(xvals=None, yrange=None, pen=None)

    Arguments: |
    xvals | A list of x values (in data coordinates) at which to draw ticks.
    yrange | A list of [low, high] limits for the tick. 0 is the bottom of the view, 1 is the top. [0.8, 1] would draw ticks in the top fifth of the view.
    pen | The pen to use for drawing ticks. Default is grey. Can be specified as any argument valid for `mkPen`

  `dataBounds`(*args, **kargs)

    Called by ViewBox for determining the auto-range bounds. By default, UIGraphicsItems are excluded from autoRange.

  `paint`(self, painter: PySide2.QtGui.QPainter, option: PySide2.QtWidgets.QStyleOptionGraphicsItem, widget: typing.Union[PySide2.QtWidgets.QWidget, NoneType] = None)
  `setPen`(*args, **kwargs)

    Set the pen to use for drawing ticks. Can be specified as any arguments valid for `mkPen`

  `setXVals`(vals)

    Set the x values for the ticks.

    Arguments: |
    vals | A list of x values (in data/plot coordinates) at which to draw ticks.

  `setYRange`(vals)

    Set the y range [low, high] that the ticks are drawn on. 0 is the bottom of the view, 1 is the top.